===========================
Django Google Drive Storage
===========================

This is a `Django Storage <https://docs.djangoproject.com/en/1.7/ref/files/storage/>`_ implementation that uses `Google Drive <https://drive.google.com>`_ as backend for storing data.

Documentation and Installation instructions
-------------------------------------------

Documentation and installation instructions can be found at `Read The Docs <http://django-googledrive-storage.readthedocs.org/>`_.